users.Authority (Authority) — amici1

# `users.Authority` (Authority)

Authority(id, user, authorized)

Master tables : users.Authorities (Authorities)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Author (user) : The user who gives the right of representation. author of this authority

- User (authorized) : The user who gets the right to represent the author

- Name (name_column) : See `lino.modlib.users.models.Authority.name_column`.

- (None) (navigation_panel) : See `lino.modlib.users.models.Authority.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.users.models.Authority.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Author | The user who gives the right of representation. author of this authority
authorized | User | The user who gets the right to represent the author
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |